/*========================================================================
     "gpop3atm"  Gaussian output post processor 3
        - create .gpo data for atomic species

             Copyright (c) 2002-2009 by A. Miyoshi, Univ. Tokyo
                                     created: Dec.  19, 2004
                                      edited: Jan.  13, 2005
                                      edited: Nov.  19, 2007
                                      edited: Jan.   2, 2009
--------------------------------------------------------------------------
 usage: gpop3atm basename [-tst]
--------------------------------------------------------------------------
 - Create baseneme.gpo file according to the information provided in
    basename.mod file.
 - With option '-tst' basename.tst is also created.
 - Keywords allowed in .mod file are:
    atomicNumber an(int)
    gElec g(int)
    eStates n(int) {g(int) e(double)} * n
    SCFenergy eSCF(double)
    energyTST eTST(double)
========================================================================*/

#include "gpoplibt.h"

/*===== main function ==================================================*/

int main(int argc, char *argv[]) {
  int outTST = false, atmcNbr = 1, one_int = 1, nes, ies, idtk;
  string opt, basfln, modfln, slin, key, atmcSym;
  vector<string> modtkn;
  jobInfos jbinf;
  molecGeom molc;
  freqTable frtab;
  modInfoTST miTST;
  atomCoord acrd;
  eigenState elst;
  ifstream inf;

  showRevision();
  if ((argc < 2) || (argc > 3))
    { cout << "usage: gpop3atm basename [-tst]\n"; return 1; }
  if (argc == 3) {
    opt = argv[2];
    if (opt != "-tst")
      { cout << "usage: gpop3tst basename [-tst]\n"; return 1; }
    else { outTST = true; }
  }
  basfln = argv[1]; modfln = basfln + ".mod";

  jbinf.SCFenergy = "0.";
  molc.gElec = 1;
  inf.open(modfln.c_str());
  while (getLineGpop(inf, slin) == NORM) {
    modtkn = splitTokens(slin, " ");
    if (modtkn.size() < 2)
      { cout << "Wrong mod-input.\n"; inf.close(); return 1; }
    key = modtkn[0];
    if (key == "atomicNumber")
      { atmcNbr = atoi(modtkn[1].c_str()); }
    else if (key == "gElec")
      { molc.gElec = atoi(modtkn[1].c_str()); }
    else if (key == "SCFenergy")
      { jbinf.SCFenergy = modtkn[1]; }
    else if (key == "energyTST")
      { miTST.energyTST = atof(modtkn[1].c_str()); }
    else if (key == "eStates") {
      nes = atoi(modtkn[1].c_str());
      for (ies = 0; ies < nes; ies++) {
        idtk = ies * 2 + 2;
        elst.deg = atoi(modtkn[idtk].c_str());
        elst.energy = atof(modtkn[idtk + 1].c_str());
        miTST.eStates.push_back(elst);
      }
    } else { cout << "Warning: Invalid key [" << key << "].\n"; }
  }
  inf.close();

  atmcSym = elm.getAtmcSym(atmcNbr);
  jbinf.version = "-"; jbinf.revision = "-";
  jbinf.comment = atmcSym + " atom";
  jbinf.methodIdx = -1; jbinf.setMethodProp();
  molc.nAtms = 1; molc.nVibm = 0; molc.isLinear = false;
  molc.pntGrp = "KH"; molc.elState = "";
  molc.rotSymNbr = 1; molc.numIsomers = 1;
  molc.molW = elm.getAtmcWeight(atmcNbr);
  molc.chemform.insert(make_pair(atmcNbr, one_int));
  acrd.atomicNumber = atmcNbr; molc.geom.push_back(acrd);

  if (outFileGpo(basfln, jbinf, molc, frtab, miTST) == ERRE) { return 1; }
  if (outTST) {
    if (outFileTst(basfln, jbinf, molc, frtab, miTST) == ERRE) { return 1; }
  }
  return 0;
}

